type Platform = "darwin" | "win32";
interface DesktopWindow {
    title: string;
    rawContents: string;
    domain?: string;
    selectedText?: string;
}
/**
 * A third party application running on the user's computer.
 * @todo consider making focusedWindow an optional parameter,
 * add additional windows as an array
 */
interface DesktopApplication {
    name: string;
    focusedWindow: DesktopWindow;
}
/**
 * Details about the Highlight app environment, like the version.
 */
interface HighlightEnvironment {
    version: string;
    requestType?: string;
}
/**
 * Details about the environment that the user is currently in, such as the operating system.
 */
interface DesktopEnvironment {
    platform: Platform;
    /**
     * The scanned OCR contents of the user's entire screen.
     */
    ocrScreenContents?: string;
    screenshotPath?: string;
    clipboardText?: string;
    highlight?: HighlightEnvironment;
    screenshotBase64?: string;
}
/**
 * The base context that is available to all prompts.
 */
interface BasePromptContext {
    environment: DesktopEnvironment;
}
/**
 * A more modern context object that seperates the foregrounded application
 * and the environment in which Highlight is running.
 */
interface HighlightContext extends BasePromptContext {
    application: DesktopApplication;
    environment: DesktopEnvironment;
    /**
     * A string that represents the user's intent with the context of the application.
     */
    userIntent?: string;
    /**
     * The suggestion the user selected from the suggestions list.
     */
    suggestion?: string;
    attachments?: Attachment[];
}
/**
 * An item the user has elected to attach to provide additional context about their query.
 */
interface Attachment {
    type: "audio" | "clipboard" | "screenshot";
    value: string;
}
/**
 * A message to be sent to an LLM through a chat like interface.
 */
interface LLMMessage {
    content: string;
    role: "system" | "user";
}
type HighlightEvent = "onContext" | "onTextPredictionUpdate" | "onTextPredictionDone";

interface HighlightAPI {
    /**
     * A secure store for your app to save data.
     */
    appStorage: {
        isHydrated: () => boolean;
        whenHydrated: () => Promise<boolean>;
        all: () => Record<string, any>;
        get: (key: string) => any;
        set: (key: string, value: any) => void;
        setAll: (value: Record<string, any>) => void;
        delete: (key: string) => void;
        clear: () => void;
    };
    app: {
        /**
         * Tell Highlight your app should run in the background.
         * If you don't have permission to run in the background, this will throw an error.
         * @see Highlight.permissions.requestBackgroundPermission
         */
        setBackgroundStatus: (status: boolean) => Promise<void>;
    };
    permissions: {
        /**
         * Request permission to run your app in the background when Highlight starts.
         */
        requestBackgroundPermission: () => Promise<boolean>;
    };
    user: {
        /**
         * Get the facts the user has set for themselves. This could be "I only want concise responses", "my name is...", etc.
         */
        getFacts: () => Promise<string[]>;
        /**
         * Set the ASR to run in realtime (1.1 seconds). This will use about 10x more GPU processing than non realtime, so once you are finished needing realtime transcripton, you should also set this to false
         * @param {boolean} isActive
         */
        setAsrRealtime: (isActive: boolean) => void;
        /**
         * Get the audio captions from the user's device.
         * @param {boolean} longAudio - If you want to get the long audio captions. Fetch ASR text for the last 2 hours
         * @returns {string} - The audio captions.
         */
        getAudio: (longAudio: boolean) => Promise<string>;
        /**
         * Get the microphone activity as a number from 0-5. 0 means no audio, 5 means absolute loudest.
         * @param {number} lastNumMs - specifies the duration in milliseconds for which you want to calculate the average energy of the mic input.
         * @returns {number} - The microphone activity from 0-5.
         */
        getMicActivity: (lastNumMs: number) => Promise<number>;
        getScreenshot: () => Promise<string>;
        /**
         * Get an email address for the user, for privacy, this address will forward to the user's real email address.
         * @returns {string} - The email address.
         */
        getEmail: () => Promise<string>;
        /**
         * Fetches the context of the window (ignoring Highlight), the same as the eventListener "onContext".
         * May be polled for repeated updates.
         */
        getContext: () => Promise<HighlightContext>;
    };
    auth: {
        /**
         * Get an access token and refresh token that can be used to validate the user's session on your backend.
         */
        signIn: () => Promise<{
            accessToken: string;
            refreshToken: string;
        }>;
    };
    inference: {
        /**
         * Get a stream of text predictions from an LLM.
         * @param messages The messages to send to the LLM.
         * @returns A stream of text predictions.
         */
        getTextPrediction: (messages: LLMMessage[]) => AsyncGenerator<string>;
    };
    /**
     * Adds an event listener for your Highlight app.
     * @param event The name of the event to listen for.
     * @param listener The listener Highlight will call when the event is emitted.
     */
    addEventListener: (event: HighlightEvent, listener: (...args: any[]) => void) => void;
    /**
     * Removes an event listener that you previously registered.
     */
    removeEventListener: (event: HighlightEvent, listener: (...args: any[]) => void) => void;
    once: (event: HighlightEvent, listener: (...args: any[]) => void) => void;
}
declare const api: HighlightAPI;

export { type Attachment, type BasePromptContext, type DesktopApplication, type DesktopEnvironment, type DesktopWindow, type HighlightContext, type HighlightEnvironment, type HighlightEvent, type LLMMessage, type Platform, api as default };
